#!/usr/bin/perl
### rUYedt01.perl  -*- Perl -*-
## Prepare a PDF file with some labels.

### Ivan Shmakov, 2019

## To the extent possible under law, the author(s) have dedicated
## all copyright and related and neighboring rights to this software
## to the public domain worldwide.  This software is distributed
## without any warranty.

## You should have received a copy of the CC0 Public Domain Dedication
## along with this software.  If not, see
## <http://creativecommons.org/publicdomain/zero/1.0/>.

### Code:

use common::sense;
use English qw (-no_match_vars);

# require Data::Dump;
require List::Util;
require PDF::API2;

my ($font_fn)
    = ("/usr/share/fonts/truetype/dejavu/DejaVuSerif.ttf");

my @labels_s = do {
    use utf8;
    ## .
    qw {
        Соединители
        Конденсаторы
        Конденсаторы
        Сердечники
        Управление
        РЧ-тракт
        Упаковка
        Измерение
        Инструмент
        Неудачи
    };
};

my $mm_pt
    = (72 / 25.4);

my $pd
    = PDF::API2->new ();

my $font
    = $pd->ttfont ($font_fn);

my $page
    = $pd->page ();
$page->mediabox ("A4");

## Set up a graphics context for the page
my $gc
    = $page->gfx ();
$gc->linewidth (2);

my $y_step
    = List::Util::min (85.04, ((297 - 30) * $mm_pt / (@labels_s)));
my $y_pos
    = (((297 - 15) * $mm_pt) - (@labels_s * $y_step));
my @labels = map {
    my $c
        = $page->text ();
    $c->font ($font, .75 * $y_step);
    $c->translate ((.5 * 210 * $mm_pt), $y_pos + .25 * $y_step);
    $c->text_center ($_);

    ## Add a border as well
    $gc->move (20 * $mm_pt, $y_pos);
    $gc->hline ((210 - 20) * $mm_pt, $y_pos);
    $gc->stroke ();

    $y_pos
        += $y_step;

    ## .
    $c;
} (@labels_s);

## Add one more border
$gc->move (20 * $mm_pt, $y_pos);
$gc->hline ((210 - 20) * $mm_pt, $y_pos);
$gc->stroke ();

my $out
    = \*STDOUT;
if (-t $out) {
    warn ("W: Will not write PDF to a tty");
    warn ("N: Would have written ", length ($pd->stringify ()), " octets");
} else {
    $pd->saveas ("/dev/fd/" . $out->fileno ());
}

### Emacs trailer
## Local variables:
## coding: utf-8
## indent-tabs-mode: nil
## ispell-local-dictionary: "american"
## End:
### rUYedt01.perl ends here
